.. notebooks to be included in dice docs

Example notebooks

.. toctree::
   :maxdepth: 2
   :caption: Notebooks:
   
   DiCE_getting_started
   DiCE_feature_importances.ipynb
   DiCE_multiclass_classification_and_regression.ipynb
   DiCE_model_agnostic_CFs.ipynb
   DiCE_with_private_data
   DiCE_with_advanced_options
   DiCE_getting_started_feasible

